package com.flossom.common.core.mapper;

import com.flossom.common.core.domain.entity.WxOtherSetting;

import java.util.List;


/**
 * 其他配置Mapper接口
 *
 * @author flossom
 * @date 2023-12-13
 */
public interface WxOtherSettingMapper {
    /**
     * 查询其他配置
     *
     * @param id 其他配置主键
     * @return 其他配置
     */
    public WxOtherSetting selectWxOtherSettingById(Long id);

    /**
     * 查询其他配置列表
     *
     * @param wxOtherSetting 其他配置
     * @return 其他配置集合
     */
    public List<WxOtherSetting> selectWxOtherSettingList(WxOtherSetting wxOtherSetting);

    /**
     * 新增其他配置
     *
     * @param wxOtherSetting 其他配置
     * @return 结果
     */
    public int insertWxOtherSetting(WxOtherSetting wxOtherSetting);

    /**
     * 修改其他配置
     *
     * @param wxOtherSetting 其他配置
     * @return 结果
     */
    public int updateWxOtherSetting(WxOtherSetting wxOtherSetting);

    /**
     * 删除其他配置
     *
     * @param id 其他配置主键
     * @return 结果
     */
    public int deleteWxOtherSettingById(Long id);

    /**
     * 批量删除其他配置
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWxOtherSettingByIds(Long[] ids);
}
